$Title -- DC Optimal Dispatch Model

$OFFSYMXREF
option sysout = on;
$onmulti
* allows multiple redefinition of tables


SCALAR
     Swing      Select the index of the swing bus / 1 /
     WITHLOSS   Set to one for losses and zero for no losses / 0 /
;

SETS
* The following parameters must be set to describe the network
* Bus names should be a maximum of 8 characters     
     P   Players / 1*5 /
     N   Buses 
         /
         NW, SF, MID, DC, LA, SD, LV, IID, AZ, NW2
         /
     M   Links / 1*12 /
     G   Generators / 1*25 /
     L   Loads / 1*8 /
     INT Interface Constraints /1*1/
     IntZRows Number of links included in interface constraints /1*2/
     IntYRows Number of buses included in interface constraints /1*1/

* The column data are fixed and set up the tables below

     GenCols Number of Columns in GenData   / 1*6 /
     LoadCols Number of Columns in LoadData / 1*6 /
     LinkCols Number of Columns in LinkData / 1*6 /
     IntZCols Number of Columns in IntZData / 1*3 /
     IntYCols Number of Columns in IntYData / 1*3 /
     IntUCols Number of Columns in IntUData / 1*2 /
;


Table LinkData(M,LinkCols)
* Column 1:  From bus index
* Column 2:  To bus index
* Column 3:  Resistance    
* Column 4:  Reactance
* Column 5:  Minimum flow
* Column 6:  Maximum flow

    1    2     3     4      5       6  
1   2    1  0.05  0.25   -4.8     3.6  
2   3    2  0.05  0.25   -4.0     4.0  
3   4    3  0.05  0.25   -4.0     4.0  
4   3    5  0.05  0.25   -2.0     3.0  
5  10    5  0.05  0.25   -1.9     3.0  
6   5    6  0.05  0.25   -1.8     1.8   
7   7    5  0.05  0.25   -4.0     4.0 
8   8    5  0.05  0.25   -4.0     4.0 
9   8    6  0.05  0.25   -0.9     0.9 
10  7    8  0.05  0.25   -4.0     4.0 
11  9    7  0.05  0.25    0.0     3.0 
12  9    8  0.05  0.25    0.0     3.0 
;

Table GenData(G,GenCols) 
* Column 1:  Price at which supply is zero at a given bus.
* Column 2:  Inverse of slope of supply curve (dQ/dP) at a bus. ENTER INF
*            FOR HORIZONTAL AND ZERO FOR VERTICAL SUPPLY CURVES.
* Column 3:  Minimum supply at a given bus.
* Column 4:  Maximum supply at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning generation.

        1          2          3     4    5    6
1    0.11        INF          0 25.08    1    1
2    1.20        INF          0 10.98    1    1
3    0.12        INF          0  1.44    1    1
4    6.00        INF          0  2.97    1    1
5    3.60        INF          0  6.71    2    2
6    0.13        INF          0  9.59    2    2
7    6.10        INF          0  2.72    2    2
8    3.20        INF          0  1.05    4    2
9    0.14        INF          0  2.27    4    2
10   0.15        INF          0  2.74    5    3
11   0.20        INF          0  2.71    5    3
12   3.10        INF          0  3.92    5    3
13   8.50        INF          0 14.42    5    3
14   2.80        INF          0  1.69    6    4
15   0.16        INF          0  0.45    6    4
16   3.70        INF          0  0.77    7    3
17   0.17        INF          0  1.12    7    3
18   1.30        INF          0  2.27    7    3
19   8.60        INF          0  0.42    8    4 
20   0.18        INF          0  1.78    9    5
21   1.25        INF          0  6.57    9    5
22   3.40        INF          0  1.71    9    5
23   0.19        INF          0  2.77    9    5
24   7.00        INF          0  2.51    9    5
25   0.11        INF          2   2.5   10    1
;

Table LoadData(L,LoadCols)
* Column 1:  Price at which demand is zero at a given bus. ANY NUMBER CAN
*            BE ENTERED FOR VERTICAL DEMAND CURVES.
* Column 2:  Inverse of slope of demand curve (dQ/dP) at a bus.
*            ENTER -INF FOR HORIZONTAL AND ZERO FOR VERTICAL DEMAND CURVES.
* Column 3:  Minimum load at a given bus. MIN LOAD SHOULD EQUAL MAX LOAD FOR
*            VERTICAL DEMAND CURVES.
* Column 4:  Maximum load at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning load.

           1       2      3          4      5    6
1      54.00      -1      0      39.00      1    1
2      29.55      -1      0      14.55      2    2
3      17.80      -1      0       2.80      2    2
4      34.31      -1      0      19.31      5    3
5      18.00      -1      0       3.00      6    4
6      17.57      -1      0       2.57      7    3
7      15.52      -1      0       0.52      8    4
8      26.50      -1      0      11.50      9    5
;


Table IntZData(IntZRows,IntZCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of link included in interface constraint.
* Column 3:  Coefficient for link in interface constraint.

        1          2          3
1       1         11          1
2       1         12          1
;

Table IntYData(IntYRows,IntYCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of bus included in interface constraint.
* Column 3:  Coefficient for bus in interface constraint.

        1          2          3
1       1          1          0
;

Table IntUData(INT,IntUCols) 
* Column 1:  Lower bound on the interface constraint.
* Column 2:  Upper bound on the interface constraint.

         1         2
1      -10         4
;

* With these tables, the model links to the main GAMS program
* for implementing the DC optimal power flow computation.

$include dcmain.gms
