$Title -- DC Optimal Dispatch Model for DC33 Network

$OFFSYMXREF
option sysout = on;
$onmulti
* allows multiple redefinition of tables


SCALAR
     Swing      Select the index of the swing bus / 1 /
     WITHLOSS   Set to one for losses and zero for no losses / 0 /
;

SETS
* The following parameters must be set to describe the network
* Bus names should be a maximum of 8 characters     
     P   Players / 1*2 /
     N   Buses 
         /
         1*3
         /
     M   Links / 1*3 /
     G   Generators / 1*8 /
     L   Loads / 1*7 /
     INT Interface Constraints /1*1/
     IntZRows Number of links included in interface constraints /1*2/
     IntYRows Number of buses included in interface constraints /1*1/

* The column data are fixed and set up the tables below

     GenCols Number of Columns in GenData   / 1*6 /
     LoadCols Number of Columns in LoadData / 1*6 /
     LinkCols Number of Columns in LinkData / 1*6 /
     IntZCols Number of Columns in IntZData / 1*3 /
     IntYCols Number of Columns in IntYData / 1*3 /
     IntUCols Number of Columns in IntUData / 1*2 /
;


Table LinkData(M,LinkCols)
* Column 1:  From bus index
* Column 2:  To bus index
* Column 3:  Resistance    
* Column 4:  Reactance
* Column 5:  Minimum flow
* Column 6:  Maximum flow

    1    2       3       4      5       6  
1   1    3 0.00005 0.00025   -600     600 
2   1    2 0.00005 0.00025  -2000    2000 
3   2    3 0.00005 0.00025  -2000    2000 
;

Table GenData(G,GenCols) 
* Column 1:  Price at which supply is zero at a given bus.
* Column 2:  Inverse of slope of supply curve (dQ/dP) at a bus. ENTER INF
*            FOR HORIZONTAL AND ZERO FOR VERTICAL SUPPLY CURVES.
* Column 3:  Minimum supply at a given bus.
* Column 4:  Maximum supply at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning generation.

        1          2          3     4    5    6
1     3.5        INF          0  2000    1    1
2       4        INF          0   500    2    2
3       5        INF          0   500    2    2
4       6        INF          0   500    2    2
5       7        INF          0   500    2    2
6       8        INF          0   100    2    2
7       9        INF          0    25    2    2
8    11.5        INF          0  2000    3    2
;             
              
Table LoadData(L,LoadCols)
* Column 1:  Price at which demand is zero at a given bus. ANY NUMBER CAN
*            BE ENTERED FOR VERTICAL DEMAND CURVES.
* Column 2:  Inverse of slope of demand curve (dQ/dP) at a bus.
*            ENTER -INF FOR HORIZONTAL AND ZERO FOR VERTICAL DEMAND CURVES.
* Column 3:  Minimum load at a given bus. MIN LOAD SHOULD EQUAL MAX LOAD FOR
*            VERTICAL DEMAND CURVES.
* Column 4:  Maximum load at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning load.

           1       2      3          4      5    6
1          0       0      0          0      3    1
2          0       0      0          0      3    1
3          0       0      0          0      3    1
4       9.75       0   1800       1800      3    1
5          0       0      0          0      3    1
6      27.33       0      0          0      3    2
7        100       0      0          0      3    2
;


Table IntZData(IntZRows,IntZCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of link included in interface constraint.
* Column 3:  Coefficient for link in interface constraint.

        1          2          3
1       1          1          1
2       1          3          1
;

Table IntYData(IntYRows,IntYCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of bus included in interface constraint.
* Column 3:  Coefficient for bus in interface constraint.

        1          2          3
1       1          1          0
;

Table IntUData(INT,IntUCols) 
* Column 1:  Lower bound on the interface constraint.
* Column 2:  Upper bound on the interface constraint.

         1         2
1    -2000      2000
;

* With these tables, the model links to the main GAMS program
* for implementing the DC optimal power flow computation.

$include dcmain.gms
