* DCMAIN.GMS Version 3.08

* In theory, there should be no need to change this code.
* All the information needed to describe the network, loads and constraints
* should be in the tables in filename.MOD.

*  The batch file DCGAMS.BAT is used to merge filename.MOD and DCMAIN.GMS
*  The command is 
*                 DCGAMS filename

* This model allows for thermal limits on lines; interface limit combining
* lines and buses; losses or no losses in calculating prices.

* Created 7/21/94
* Modified 8/9/94 HDF
* Modified 12/25/94 by Bill Hogan
*  to introduce interface limits in data tables
*  and provide an option to include losses.

* Modified 12/28/94 by Bill Hogan to allow redundant links with both ends
* connected to the same node.  This provides a simple way to remove links
* without having to renumber all the line indexes.
*
* Modified 1/31/95 by Bill Hogan to separate prices into generation, losses
* and congestion costs relative to the swing bus.
*
* Modified 9/9/95 by Bill Hogan to add print out for generators.
*
* Modified 10/29/95 by Bill Hogan to correct marginal cost calculation
* in player printout.
*
* Modified 12/2/96 by Bill Hogan to correct error in pricing in the case of 
* interface constraints that include nodal net inputs in addition to the
* flows on lines.  Previous version correct for flows on lines but not for
* nodal inputs.
*
* (3.06) Created 9/4/98 by Bill Hogan reformulate WITHLOSS model from Schweppe
* assumption of all losses from the swing bus to the "bus loss" model
* in which losses on a line are treated as additons to load at each end
* of the line, with each end assigned half the losses as a reduction
* in net input.  The loss price decomposition uses a parallel model with
* the same net loads other than the swing bus, with zero costs, to calculate
* the cost of losses as the marginal prices.  This uses the marginal 
* condition that the incremental losses come from the swing bus, but 
* accounts for the change in the flows dictated by the losses.  This numerical
* approach works for any loss model formulation and is more general than the
* special equations used with the Schweppe formulation.
*
* (3.07) 10/17/98 Corrects a reporting error in the generation by player
*
* (3.08) 2/21/99  Corrects the price decomposition for the case when the
* reference (swing) bus price is negative.
*



* Setting report (lst file) options
option NLP = minos5;   
option LP = minos5;
* option NLP = conopt;   
* option LP = conopt;
option solveopt = REPLACE;   
options decimals=7;
option solprint = on;
options limrow=20;
options limcol=20;
option iterlim = 10000000;
option reslim  = 10000000;
file report /PRICE.PUT/;
put report;
report.pw=80;

*---------------------------------------------------------------------------

* OPTIMAL DISPATCH MODEL - SETUP


PUT 'DCMODEL V3.08: ',SYSTEM.IFILE,' ON ',SYSTEM.DATE,' AT ',SYSTEM.TIME;
PUT//'Note:  This simplified DC model is designed to illustrate constrained network';
PUT/'       dispatch and pricing.  However, it does not account for the spinning';
PUT/'       reserve or contingency constraints needed for a full analysis of a';
PUT/'       security constrained dispatch and the true (lower) system capacity.';
PUT/;

SCALAR
     PuEquiv /1/
     TotGen
     TotLoad
     Losses
     SwingP      Swing Bus Price
     Gencost     Total generation cost
     Genpmts     Total generation payments
     Loadval     Total Load Value
     Loadpmts    Total Demand Payments
     tempc
     tempr
     temptc
     temptr
     tempq
     runtot1
     runtot2
     runtot3
     runtot4
;

$ONTEXT     
     PuEquiv is the denominator for converting loads to p.u. basis.
     Equal to one if no conversion is necessary.
$OFFTEXT
     
ALIAS (N,Np),(I,N),(Ip,N),(J,N),(K,M),(IZ,IntZRows),(IY,IntYRows); 

PARAMETERS

* The following parameters are the columns of the GenData table
     NoSupply(G)    The price at which supply (generation) is zero for G at node GenBusIdx(G)
     InvSupply(G)   The inverse of the slope of the supply curve of G (positive)
     MinSupply(G)   The minimum supply of G
     MaxSupply(G)   The maximum generation of G
     GenBusIdx(G)   Index to bus number 
     GenPlayer(G)   Player owning this generation

* The follwing parameters are the column of the LoadData table
     NoDemand(L)    The price at which demand (load) is zero for L at node LoadBusIdx(L)
     InvDemand(L)   The inverse of the slope of the demand curve of L (negative)
     MinDemand(L)   The minimum load of L
     MaxDemand(L)   The maximum demand of L
     LoadBusIdx(L)  Index to bus number 
     LoadPlayer(L)  Player consuming this load
     
$ONTEXT
     Demand and supply curves are assumed to be linear.
     If NoDemand is zero, there is is no demand at a bus.
     InvDemand is the change in demand with respect to changing price.
     If NoSupply is infinite, there is no generation at a bus.
     InvSupply is the change in supply with respect to changing price.
$OFFTEXT

*  The following parameters are the columns of the linkdata table
     FromBus(M)     From Bus for Link M
     ToBus(M)       To Bus for Link M
     Resist(M)      Resistances
     React(M)       Reactances
     Zpmin(M)       Minimum flow on line
     Zpmax(M)       Maximum flow on line
     
*  The following parameters are calculated from the data in the tables
     GVECTOR(M)           
     Omega(M)       
     Gmatrix(M,M)
     Omatrix(M,M)
     Rvector(M)
     Incidence(M,N) 
     Incidtest(M)   Test that the incidence matrix sums to zero
     RealInj(N) Net real injections (positive for load)
     SwingBus(N)    A flag for if bus N is a swing bus     
     MktPrice(N)    The market price at N
     GenLossP(N)    The generation plus losses price at N
     CongestP(N)    The congestion cost at N
     ZloMult(M)     The transmission flow lower bound multiplier
     ZupMult(M)     The transmission flow upper bound multiplier
     Zintmulo(INT)  The transmission interface lower bound multiplier
     Zintmuup(INT)  The transmission interface upper bound multiplier
     IntZCoef(INT,M) The coefficients for the links in interface limit
     IntYCoef(INT,N) The coefficients for the buses in interface limit
     IntUlo(INT)    The lower bounds for interface limits
     IntUup(INT)    The upper bounds for interface limits
     IndGenS(G)     The Generation solution from model
     IndLoadS(L)    The Load solution from model
     LoadSol(N)     The load solution to use in marginal loss calculation
     GenSol(N)      The gen solution to use in marginal loss calculation
     ZpSol(M)      The line flow solution to use in marginal loss calculation
     ;       

     FromBus(M) = LinkData(M,'1');
     ToBus(M) = LinkData(M,'2');
     Resist(M) = LinkData(M,'3');
     React(M) = LinkData(M,'4');
     Zpmin(M) = LinkData(M,'5')/PuEquiv;
     Zpmax(M) = LinkData(M,'6')/PuEquiv;

     NoSupply(G) = GenData(G,'1');
     InvSupply(G) = GenData(G,'2')/PuEquiv;  
     MinSupply(G) = GenData(G,'3')/PuEquiv;
     MaxSupply(G) = GenData(G,'4')/PuEquiv;  
     GenBusIdx(G) = GenData(G,'5');
     GenPlayer(G) = GenData(G,'6');
     
     NoDemand(L) = LoadData(L,'1');
     InvDemand(L) = LoadData(L,'2')/PuEquiv;  
     MinDemand(L) = LoadData(L,'3')/PuEquiv;  
     MaxDemand(L) = LoadData(L,'4')/PuEquiv;
     LoadBusIdx(L) = LoadData(L,'5');
     LoadPlayer(L) = LoadData(L,'6');
                                 
Loop(N,SwingBus(N)$(ORD(N) eq Swing) = 1;);

Incidence(M,N) = 0;


* Note that this formulation of Incidence allows links that go from and
* to the same bus, leaving a row of zeros in Incidence.

Loop(M,
     Loop(N$(Ord(N) eq FromBus(M)), Incidence(M,N) = Incidence(M,N) +1; );
     Loop(N$(Ord(N) eq ToBus(M)), Incidence(M,N) = Incidence(M,N) -1; );
);

* Check for improper entry of links with only one end in Node set.
Incidtest(M) = 0;
Loop(M,Incidtest(M)=Sum(N,Incidence(M,N)));
Loop(M,
PUT$(Incidtest(M))// "Unbalanced Incidence Matrix at Link",Ord(M);
ABORT$(Incidtest(M)) "Unbalanced Incidence Matrix at Link";
);

IntZCoef(INT,M) = 0;
IntYCoef(INT,N) = 0;
IntUlo(INT) = 0;   
IntUup(INT) = 0;   

Loop(IZ,
Loop(INT$(IntZData(IZ,'1') eq Ord(INT)),
Loop(M$(IntZData(IZ,'2') eq Ord(M)),IntZCoef(INT,M)=IntZData(IZ,'3'))
));
Loop(IY,
Loop(INT$(IntYData(IY,'1') eq Ord(INT)),
Loop(N$(IntYData(IY,'2') eq Ord(N)),IntYCoef(INT,N)=IntYData(IY,'3'))
));
Loop(INT,IntUlo(INT)=IntUData(INT,'1'));
Loop(INT,IntUup(INT)=IntUData(INT,'2'));


* Initializing calculated parameters
     GVECTOR(M) = 0;
     Omega(M) = 0;
     Gmatrix(M,M) = 0;
     Omatrix(M,M) = 0;
     Rvector(M) = 0;

* Defining intermediate variables used to calculate flows (pg. 47 of TR)
     GVECTOR(M) = Resist(M)/(SQR(Resist(M))+SQR(React(M)));
     OMEGA(M) = React(M)/(SQR(Resist(M))+SQR(React(M)));
     Loop(M, Gmatrix(M,M) = GVECTOR(M); Omatrix(M,M) = Omega(M););
     Loop(M, Rvector(M) = GVECTOR(M)/Sqr(Omega(M)););

DISPLAY Omatrix;
DISPLAY INCIDENCE;

* OPTIMAL DISPATCH MODEL FOLLOWS *

FREE VARIABLES

     Zp(M)       Flow on each line
     Delta(N)    Angle at each bus -- swing bus equals zero.
     NetInput(N) The net input at each bus, generation minus load.
     Welfare     Total benefits of load less total cost of generation
     ;
     
POSITIVE VARIABLES

     Gen(N)      Generation at each bus
     Load(N)     Load at each bus
     IndivLoad(L) Load of each player
     IndivGen(G) Generation of each player

EQUATIONS

     Con0(N)
     Con1(N)        
     Con2(M)       
     Con3(N)
     Con4(M)
     Con5(M)
     Con6(L)
     Con7(G)
     Con8(L)
     Con9(G)
     Con10lo(INT)
     Con10up(INT)
     Con11(N)
     Con12(N)
     Con12Loss(N)  Allow a little slack at swing bus in loss calculation
     FixLoad(N)    Fix load solution for loss model
     FixGen(N)     Fix generation solution for loss model
     ObjFnp 
     LossObjFnp ;

Con0(N) .. Gen(N) - Load(N) - NetInput(N) =E= 0;

Con1(N) .. NetInput(N) - Sum(K, Incidence(K,N) * Zp(K))
           - (WITHLOSS) * 0.5*Sum(K,Rvector(K)*Sqr(Incidence(K,N) * Zp(K)))
           =E= 0;

Con2(K).. Zp(K) - Sum(M, Omatrix(K,M) * Sum(J, Delta(J)*Incidence(M,J)))
          =E= 0;

Con3(N).. SwingBus(N) * Delta(N) =E= 0;

Con4(M).. Zp(M) - Zpmax(M) =L= 0;
 
Con5(M).. Zp(M) - Zpmin(M) =G= 0;

Con6(L).. IndivLoad(L) - MinDemand(L) =G= 0;

Con7(G).. IndivGen(G) - MaxSupply(G) =L= 0;

Con8(L).. IndivLoad(L) - MaxDemand(L) =L= 0;

Con9(G).. IndivGen(G) - MinSupply(G) =G= 0;

Con10lo(INT)..  Sum(M,Zp(M)*IntZCoef(INT,M)) - Sum(N,(NetInput(N))*IntYCoef(INT,N)) =G= IntUlo(INT);

Con10up(INT)..  Sum(M,Zp(M)*IntZCoef(INT,M)) - Sum(N,(NetInput(N))*IntYCoef(INT,N)) =L= IntUup(INT);

Con11(N).. Load(N) =E= Sum(L$(LoadBusIdx(L) eq ORD(N)),IndivLoad(L));

Con12(N).. Gen(N) =E=  Sum(G$(GenBusIdx(G) eq ORD(N)),IndivGen(G));

Con12Loss(N)$(SwingBus(N) ne 0).. Gen(N) =L=  Sum(G$(GenBusIdx(G) eq ORD(N)),IndivGen(G))+1;

FixLoad(N)$(SwingBus(N) eq 0).. Load(N) =E= LoadSol(N);

FixGen(N)$(SwingBus(N) eq 0)..  Gen(N) =E= GenSol(N);



ObjFnp .. Welfare =E= 
     Sum(L$(MaxDemand(L) ne 0), IndivLoad(L)*(NoDemand(L)+
        (((1/InvDemand(L))$(InvDemand(L) NE 0))*IndivLoad(L)))) +
     
* Revenue; if demand curve is vertical (InvDemand = 0), area will be exactly
* rectangular and the solution will be independant of the value of NoDemand
* since the rectangle is constant.

     Sum(L$(MaxDemand(L) ne 0), IndivLoad(L)*(NoDemand(L)-
        (NoDemand(L)+(((1/InvDemand(L))$(InvDemand(L) NE 0))*
        IndivLoad(L))))/2) -
     
* + Consumer surplus; Again, if the demand curve is vertical the solution 
* is independant of NoDemand.

     Sum(G$(MaxSupply(G) ne 0), 
        IndivGen(G)*(NoSupply(G)+(((1/InvSupply(G))$
        (InvSupply(G) NE 0))*IndivGen(G))/2));

* - Marginal cost of production; if the supply curve is horizontal 
* (InvSupply = INF), the area will be rectangular, otherwise it will be
* right-angled trapezoid given the location of the "/2".  If InvSupply = 0, 
* the program will crash, but this is OK since InvSupply is meaningless.


*
* Next specify an objective function that is sure to make the swing bus
* basic and determine the marginal price as SwingP by pushing all other
* generation and load constraints to their limits first.
* 

LossObjFnp .. Welfare =E= 

     Sum(N$(SwingBus(N) eq 0), (Load(N)-Gen(N))*(abs(SwingP)+1)*100)+ 

     Sum(N$(SwingBus(N) ne 0), (Load(N)-Gen(N))*SwingP); 
     

MODEL DISPATCH
           /con0, con1, con2, con3, con4, con5, con6, con7, con8, con9, con10lo, con10up, con11, con12, ObjFnp/;


MODEL LOSSCALC
           /con0, con1, con2, con3, con6, con7, con8, con9, con11, con12Loss, FixLoad, FixGen, LossObjFnp/;


SOLVE DISPATCH Using NLP Maximizing Welfare;

PUT$(DISPATCH.modelstat gt 2)// "Solution not found to dispatch model";
ABORT$(DISPATCH.modelstat gt 2) "Solution not found to dispatch model";

   MktPrice(N)= -CON0.M(N);
   ZupMult(M) = CON4.M(M);
   ZloMult(M) = -CON5.M(M);
   ZintMulo(INT) = CON10lo.M(INT);
   ZintMuup(INT) = CON10up.M(INT);
   Gencost= 10*(Sum(G$(MaxSupply(G) ne 0), 
      IndivGen.L(G)*(NoSupply(G)+(((1/InvSupply(G))$
      (InvSupply(G) NE 0))*IndivGen.L(G))/2)));
   Loop(N,SwingP$SwingBus(N) = MktPrice(N));
   Loadval= 10*(Sum(L$(MaxDemand(L) ne 0), IndivLoad.L(L)*(NoDemand(L)+
      (((1/InvDemand(L))$(InvDemand(L) NE 0))*IndivLoad.L(L)))) +
      Sum(L$(MaxDemand(L) ne 0), IndivLoad.L(L)*(NoDemand(L)-
      (NoDemand(L)+(((1/InvDemand(L))$(InvDemand(L) NE 0))*
      IndivLoad.L(L))))/2));
   
* Save various reporting items that will be changed by the loss decomposition

   Genpmts= Sum(N,Gen.L(N)*Mktprice(N)*10);
   TotGen= Sum(N,Gen.L(N));
   Loadpmts= Sum(N,Load.L(N)*Mktprice(N)*10);
   TotLoad= Sum(N,Load.L(N));
   Losses= TotGen-TotLoad;
   LoadSol(N) = Load.L(N);
   GenSol(N) = Gen.L(N);
   ZpSol(M) = Zp.L(M); 
   IndGenS(G) = IndivGen.L(G);  
   IndLoadS(L) = IndivLoad.L(L);


* Now solve the loss model to get losses only prices

SOLVE LOSSCALC Using NLP Maximizing Welfare;

PUT$(LOSSCALC.modelstat gt 2)// "Solution not found to loss decomposition model";
ABORT$(LOSSCALC.modelstat gt 2) "Solution not found to loss decomposition model";

   GenLossP(N) = -CON0.M(N);
   CongestP(N) = MktPrice(N)-GenLossP(N);


       PUT$WITHLOSS// "Dispatch Including Losses of ",Losses:15:5;
       PUT$(WITHLOSS Eq 0)// "Dispatch Ignoring Losses";
       PUT /'Buses',@20,'Gen',@33,'Load',@46,'Net Input',@61,'Price';
       Loop(N,PUT /Ord(N):5:0,@7,N.TL,@17,GenSoL(N):10:5,@30,LoadSoL(N):10:5,
               @43,(GenSoL(N)-LoadSoL(N)):10:5,@58,MktPrice(N):10:5);
       PUT /; 

       PUT // 'Price Decomposition Relative to Swing Bus at ';
       Loop(N,PUT$SwingBus(N) N.TL);
       PUT /'Buses',@20,'Gen&Loss',@33,'Congestion',@46,'Price';
       Loop(N,PUT /Ord(N):5:0,@7,N.TL,@17,GenLossP(N):10:5,
                @30,CongestP(N):10:5,@43,MktPrice(N):10:5);


       PUT //'Lines',@10, 'From',@19,'To',@33,'Min',@47,'Zp',
           @55,'Max',@60,'ZloMult',@69,'ZupMult';
       Loop(K,
           Loop(M,Put$(Ord(M) eq Ord(K)) /M.TL);
           Loop(N,Put$(Ord(N) eq FromBus(K)) @10,N.TL);
           Loop(N,Put$(Ord(N) eq ToBus(K)) @19,N.TL);
           PUT @28,ZpMin(K):8:2,@37,ZpSoL(K):12:5,@50,ZpMax(K):8:2,
           @59,ZloMult(K):8:3,@68,ZupMult(K):8:3);

       PUT //@26,'Interface',@41,'Lower',@56,'Upper';
       Loop(INT,
       PUT/'Trans. Interface Mult,',Ord(INT):5:0,
       @33,ZintMulo(INT):15:5,ZintMuup(INT):15:5
       );

    PUT//;
    PUT 'Individual Generator Output: ';
    PUT/;
    PUT @4,'Generator',@15,'Bus',@24,'Index',@40,'Output';
    LOOP(G,
        PUT /@9,ORD(G):4:0;
        Loop(N,Put$(Ord(N) eq GenBusIdx(G)) @15,N.TL);
        PUT @25,GenBusIdx(G):4:0,@32,IndGenS(G):15:5
        );

       PUT//'Total Generation Cost, $',@33,Gencost:15:5;
       PUT//'Total Generation, MW',@33,TotGen:15:5;
       PUT//'Total Load Value, $',@33,Loadval:15:5;
       PUT//'Total Load, MW',@33,TotLoad:15:5;
       PUT//'Total Losses, MW',@33,Losses:15:5;
       PUT//'Total Surplus, $',@33,(Loadval-Gencost):15:5;
       PUT//'Total Generation Pmts, $',@33,Genpmts:15:5;
       PUT//'Total Load Pmts, $',@33,Loadpmts:15:5;
       PUT//'Total Rents, $',@33,(Loadpmts-Genpmts):15:5;

       PUT//;
PUT/,'* LoadData:';
PUT/,'* Column 1:  Price at which demand is zero at a given bus.';
PUT/,'* Column 2:  Inverse of slope of demand curve (dQ/dP) at a bus.';
PUT/,'* Column 3:  Minimum load at a given bus.';
PUT/,'* Column 4:  Maximum load at a given bus.';
PUT/,'* Column 5:  Index to bus number.';
PUT/,'* Column 6:  Index of player owning load.';
PUT/,'            1       2       3       4       5       6';

       Loop(L, Put /L.TL:5:0,
       PUT Loaddata(L,'1'):8:2,
       PUT Loaddata(L,'2'):8:2,
       PUT Loaddata(L,'3'):8:2,
       PUT Loaddata(L,'4'):8:2,
       PUT Loaddata(L,'5'):8:0,
       PUT Loaddata(L,'6'):8:0,
                                 );
       
       PUT//;
PUT/,'* GenData:';
PUT/,'* Column 1:  Price at which supply is zero at a given bus.';
PUT/,'* Column 2:  Inverse of slope of supply curve (dQ/dP) at a bus.';
PUT/,'* Column 3:  Minimum supply at a given bus.';
PUT/,'* Column 4:  Maximum supply at a given bus.';
PUT/,'* Column 5:  Index to bus number.';
PUT/,'* Column 6:  Index of player owning generation.';
PUT/,'            1       2       3       4       5       6';

       Loop(G, Put /G.TL:5:0,
       PUT Gendata(G,'1'):8:2,
       PUT Gendata(G,'2'):8:2,
       PUT Gendata(G,'3'):8:2,
       PUT Gendata(G,'4'):8:2,
       PUT Gendata(G,'5'):8:0,
       PUT Gendata(G,'6'):8:0,
                                 );

       PUT//;
PUT/,'* LinkData:';
PUT/,'* Column 1:  From bus index   ';
PUT/,'* Column 2:  To bus index   ';
PUT/,'* Column 3:  Resistance    ';
PUT/,'* Column 4:  Reactance';
PUT/,'* Column 5:  Minimum flow';
PUT/,'* Column 6:  Maximum flow';
PUT/,'         1    2        3        4        5        6  ';

       Loop(M, Put /M.TL:5:0,
       Linkdata(M,'1'):5:0,
       Linkdata(M,'2'):5:0,
       Linkdata(M,'3'):9:5,
       Linkdata(M,'4'):9:5,
       Linkdata(M,'5'):9:1,
       Linkdata(M,'6'):9:1,
                               );

       PUT//;
PUT/,'* IntZData:';
PUT/,'* Column 1:  Index of interface constraint.';
PUT/,'* Column 2:  Index of link included in interface constraint.';
PUT/,'* Column 3:  Coefficient for link in interface constraint.';
PUT/,'         1    2        3';

       Loop(IntZRows, Put /Ord(IntZRows):5:0,
       IntZData(IntZRows,'1'):5:0,
       IntZData(IntZRows,'2'):5:0,
       IntZData(IntZRows,'3'):9:5,
                               );


       PUT//;
PUT/,'* IntYData:';
PUT/,'* Column 1:  Index of interface constraint.';
PUT/,'* Column 2:  Index of bus included in interface constraint.';
PUT/,'* Column 3:  Coefficient for bus in interface constraint.';
PUT/,'         1    2        3';

       Loop(IntYRows, Put /Ord(IntYRows):5:0,
       IntYData(IntYRows,'1'):5:0,
       IntYData(IntYRows,'2'):5:0,
       IntYData(IntYRows,'3'):9:5,
                               );

       PUT//;
PUT/,'* IntUData:'; 
PUT/,'* Column 1:  Lower bound on the interface constraint.';
PUT/,'* Column 2:  Upper bound on the interface constraint.';
PUT/,'                   1              2';

       Loop(INT, Put /Ord(INT):5:0,
       IntUData(INT,'1'):15:5,
       IntUData(INT,'2'):15:5,
                               );

LOOP(P,
   
   PUT //'--------------------------------------------------------------------------'
         
   PUT //'PLAYER',@10,P.TL,@20,
   PUT //'Generation',@1,
   PUT //'              Price                        Avg. Cost      Total',
      '     Quasi-';
   PUT /'Bus           C/KWH        MWH    Revenue      C/KWH       Cost', 
      '       Rent';
   runtot1 = 0;
   runtot2 = 0;
   runtot3 = 0;
   runtot4 = 0;
   LOOP(G$(GenPlayer(G) eq ORD(P)),
      LOOP(N$(ORD(N) eq GenBusIdx(G)),
         tempc = NoSupply(G)+(((1/InvSupply(G))$(InvSupply(G) NE INF))*IndGenS(G))/2;
         temptc = 10*tempc*IndGenS(G);
         tempr = Mktprice(N);
         temptr = 10*tempr*IndGenS(G);
         PUT /N.TL:8,tempr:11:2,IndGenS(G):11.0,temptr:11:0,tempc:11:2,
            temptc:11:0,(temptr-temptc):11:0;
      runtot1 = runtot1 + IndGenS(G);      
      runtot2 = runtot2 + temptr;
      runtot3 = runtot3 + temptc;
      runtot4 = runtot4 + temptr - temptc;
      ));

   PUT /'                    ---------- ----------            ----------',
      ' ----------',
   PUT /'                   ',runtot1:11:2,runtot2:11:0,'           ',
      runtot3:11:0,runtot4:11:0,

   
   PUT //'Load',@1,
   PUT //'              Price                      '; 
   PUT /'Bus           C/KWH        MWH       Cost'; 
   runtot1 = 0;
   runtot2 = 0;
   LOOP(L$(LoadPlayer(L) eq ORD(P)),
      LOOP(N$(ORD(N) eq LoadBusIdx(L)),
         tempc = Mktprice(N);
         temptc = 10*Mktprice(N)*IndLoadS(L);
         PUT /N.TL:8,tempc:11:2,IndLoadS(L):11:2,temptc:11:0;
      runtot1 = runtot1 + IndLoadS(L);
      runtot2 = runtot2 + temptc;
      ));
   
   PUT /'                    ---------- ----------',
   PUT /'                   ',runtot1:11:2,runtot2:11:0;

);
