$Title -- DC Optimal Dispatch Model for Network with High and Low Prices
* Here there are bounds on all the lines in the loop.

$OFFSYMXREF
option sysout = on;
$onmulti
* allows multiple redefinition of tables


SCALAR
     Swing      Select the index of the swing bus / 1 /
     WITHLOSS   Set to one for losses and zero for no losses / 0 /
;

SETS
* The following parameters must be set to describe the network
* Bus names should be a maximum of 8 characters     
     P   Players / 1*8 /
     N   Buses 
         /
         A,B,C,D,L,P,M,N,V,W,X,Y,Z
         /
*  Index: A-1,B-2,C-3,D-4,L-5,P-6,M-7,N-8,V-9,W-10,X-11,Y-12,Z-13

     M   Links / 1*14/
     G   Generators / 1*8 /
     L   Loads / 1*4 /
     INT Interface Constraints /1*1/
     IntZRows Number of links included in interface constraints /1*2/
     IntYRows Number of buses included in interface constraints /1*1/

* The column data are fixed and set up the tables below

     GenCols Number of Columns in GenData   / 1*6 /
     LoadCols Number of Columns in LoadData / 1*6 /
     LinkCols Number of Columns in LinkData / 1*6 /
     IntZCols Number of Columns in IntZData / 1*3 /
     IntYCols Number of Columns in IntYData / 1*3 /
     IntUCols Number of Columns in IntUData / 1*2 /
;


Table LinkData(M,LinkCols)
* Column 1:  From bus index    
* Column 2:  To bus index   
* Column 3:  Resistance    
* Column 4:  Reactance
* Column 5:  Minimum flow
* Column 6:  Maximum flow

    1    2       3       4      5       6  
1   1    4 0.00005 0.00025  -1000    1000
2   2    4 0.00005 0.00025  -1000    1000    
3   3    4 0.00005 0.00025  -1000    1000    
4   4    7 0.00005 0.00025    -90      90    
5   4    8 0.00005 0.00025    -90      90    
6   7   11 0.00005 0.00025    -90      90
7   8   11 0.00005 0.00025    -90      90    
8  12   11 0.00005 0.00025  -1000    1000    
9  11   10 0.00005 0.00025  -1000    1000
10 13   11 0.00005 0.00025  -1000    1000
11  5    7 0.00005 0.00025  -1000    1000
12 11    9 0.00005 0.00025  -1000    1000
13  6    8 0.00005 0.00025  -1000    1000
14  8    7 0.00005 0.00025    -50      50
;

Table GenData(G,GenCols) 
* Column 1:  Price at which supply is zero at a given bus.
* Column 2:  Inverse of slope of supply curve (dQ/dP) at a bus. ENTER INF
*            FOR HORIZONTAL AND ZERO FOR VERTICAL SUPPLY CURVES.
* Column 3:  Minimum supply at a given bus.
* Column 4:  Maximum supply at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning generation.

        1          2          3     4    5    6
1      3.5       inf          0   100    1    1
2        4       inf          0   100    1    2
3        2       inf          0   100    2    3
4        5       inf          0    50   12    4
5        7       inf          0   250   12    5
6        3       inf          0   100   13    6
7        0       inf         25    25    5    7
8     3.25       inf          0   250    6    8
;             
              
Table LoadData(L,LoadCols)
* Column 1:  Price at which demand is zero at a given bus. ANY NUMBER CAN
*            BE ENTERED FOR VERTICAL DEMAND CURVES.
* Column 2:  Inverse of slope of demand curve (dQ/dP) at a bus.
*            ENTER -INF FOR HORIZONTAL AND ZERO FOR VERTICAL DEMAND CURVES.
* Column 3:  Minimum load at a given bus. MIN LOAD SHOULD EQUAL MAX LOAD FOR
*            VERTICAL DEMAND CURVES.
* Column 4:  Maximum load at a given bus.
* Column 5:  Index to bus number.
* Column 6:  Index of player owning load.

           1       2      3          4      5    6
1        257    -0.1      0         95      9    1
2       3207    -0.1      0        390     10    2
3        100    -inf     25         25      3    2
4        100    -inf    150        150      5    2
;


Table IntZData(IntZRows,IntZCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of link included in interface constraint.
* Column 3:  Coefficient for link in interface constraint.

        1          2          3
1       1          4          1
2       1          5          1
;

Table IntYData(IntYRows,IntYCols) 
* Column 1:  Index of interface constraint.
* Column 2:  Index of bus included in interface constraint.
* Column 3:  Coefficient for bus in interface constraint.

        1          2          3
1       1          1          0
;

Table IntUData(INT,IntUCols) 
* Column 1:  Lower bound on the interface constraint.
* Column 2:  Upper bound on the interface constraint.

         1         2
1     -150       150
;

* With these tables, the model links to the main GAMS program
* for implementing the DC optimal power flow computation.

$include dcmain.gms
